@@ -18,7 +18,7 @@ build <- function(pkg = NULL, path = NULL, binary = FALSE) {
   
   if (binary) {
     cmd <- paste("CMD INSTALL ", shQuote(pkg$path), " --build", sep = "")
-    ext <- if (os() == "win") "zip" else "tgz"
+    ext <- if (.Platform$OS.type == "windows") "zip" else "tgz"
   } else {
     cmd <- paste("CMD build ", shQuote(pkg$path), 
       " --no-manual --no-vignettes", sep = "")
