@@ -28,8 +28,14 @@ load_code <- function(pkg = NULL, env = pkg_env(pkg)) {
   
   paths <- changed_files(paths)
 
-  lapply(paths, sys.source, envir = env, chdir = TRUE, 
-    keep.source = TRUE)
+  tryCatch(
+    lapply(paths, sys.source, envir = env, chdir = TRUE, 
+      keep.source = TRUE), 
+    error = function(e) {
+      clear_cache()
+      stop(e)
+    }
+  )
   
   # Load .onLoad if it's defined
   if (exists(".onLoad", env, inherits = FALSE) && 
@@ -53,7 +59,7 @@ parse_collate <- function(string) {
 #' Find all R files in given directory.
 #' @keywords internal
 find_code <- function(path) {
-  code_paths <- dir(path, "\\.[Rr]$", full = TRUE)  
+  code_paths <- dir(path, "\\.[Rr]$", full.names = TRUE)  
   with_locale("C", sort(code_paths))
 }
 
